@@ -14,6 +14,11 @@ sub new {
 
     my $y = $x->{layer}->[0];
     my $id = delete $y->{id};
+    if (ref($id)) {
+	# We're using regular XML::Simple, which yields and array
+	$id = $id->[0];
+    }
+
     my $label = delete $y->{label};
     my $matchQuery = delete $y->{matchQuery};
 
